@@ -41,11 +41,9 @@
 #include <QIcon>
 #include <QMenu>
 #include <KWindowSystem>
-#include <KWindowInfo>
 #include <KShortcutsDialog>
 #include <KStandardShortcut>
 #include <KNotifyConfigWidget>
-#include <KStartupInfo>
 
 #include "config-konversation.h"
 
@@ -53,6 +51,12 @@
 #include <KGlobalAccel>
 #endif
 
+#if HAVE_X11
+#include <KWindowInfo>
+#include <KStartupInfo>
+#include <KX11Extras>
+#endif
+
 MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
 {
     setStateConfigGroup(QStringLiteral("MainWindow"));
@@ -684,9 +688,11 @@ bool MainWindow::restore()
 
     // TODO: also save & restore any TrayIcon state, needs API in KStatusNotifierItem
 
+#if HAVE_X11
     // in case no window is shown & registered, the window manager needs to be told directly the start is done
     if (!show)
         KStartupInfo::appStarted();
+#endif
 
     return KXmlGuiWindow::restore(1, show);
 }
@@ -772,8 +778,8 @@ void MainWindow::updateTrayIcon()
             m_trayIcon = new Konversation::TrayIcon(this);
             connect(this, &MainWindow::endNotification, m_trayIcon, &Konversation::TrayIcon::endNotification);
             QMenu *trayMenu = m_trayIcon->contextMenu();
-            trayMenu->addAction(actionCollection()->action(QString::fromLatin1(KStandardAction::name(KStandardAction::Preferences))));
-            trayMenu->addAction(actionCollection()->action(QString::fromLatin1(KStandardAction::name(KStandardAction::ConfigureNotifications))));
+            trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Preferences)));
+            trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::ConfigureNotifications)));
             trayMenu->addAction(actionCollection()->action(QStringLiteral("toggle_away")));
         }
 
@@ -940,10 +946,14 @@ void MainWindow::toggleVisibility()
 {
     if (isActiveWindow())
     {
-        if (Preferences::self()->showTrayIcon())
+        if (Preferences::self()->showTrayIcon()) {
             m_trayIcon->hideWindow();
-        else
-            KWindowSystem::minimizeWindow(winId());
+        }
+#if HAVE_X11
+        else {
+            KX11Extras::minimizeWindow(winId());
+        }
+#endif
     }
     else
     {
@@ -958,21 +968,29 @@ void MainWindow::activateAndRaiseWindow()
 
 void MainWindow::activateRaiseAndMoveToDesktop(MoveToDesktopMode moveToDesktop)
 {
-    if (isMinimized())
-        KWindowSystem::unminimizeWindow(winId());
-    else if (Preferences::self()->showTrayIcon() && !isVisible())
+#if HAVE_X11
+    if (isMinimized()) {
+        KX11Extras::unminimizeWindow(winId());
+    } else if (Preferences::self()->showTrayIcon() && !isVisible()) {
         m_trayIcon->restoreWindow();
+    }
+#else
+    if (Preferences::self()->showTrayIcon() && !isVisible()) {
+        m_trayIcon->restoreWindow();
+    }
+#endif
 
     if (!isActiveWindow())
     {
         raise();
-        if (moveToDesktop == MoveToDesktop)
-        {
+#if HAVE_X11
+        if (moveToDesktop == MoveToDesktop) {
             KWindowInfo info(winId(), NET::WMDesktop);
             if (!info.onAllDesktops())
-                KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
+                KX11Extras::setOnDesktop(winId(), KX11Extras::currentDesktop());
         }
-        KWindowSystem::activateWindow(winId());
+        KX11Extras::activateWindow(winId());
+#endif
     }
 }
 
